# Configuration

Configuration covers Intro, Config Hierarchy, Config Value Structure.

## Sections

- [Intro](intro.md)
- [Config Hierarchy](config-hierarchy.md)
- [Config Value Structure](config-value-structure.md)
- [Core configuration](core-configuration.md)
- [Cascade delete settings](cascade-delete-settings.md)
- [Complete Configuration Reference](complete-configuration-reference.md)
- [Core Settings](core-settings.md)
- [Optional Settings](optional-settings.md)
